package aacs.shared;

import java.io.File;
import java.io.FileInputStream;
import java.security.MessageDigest;

public class Utils {

    public static String toHexString(byte[] ba) {

        if (ba == null) {
            return null;
        }

        final char[] binToHexChar = {
            '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F'
        };
        StringBuffer sb           = new StringBuffer(ba.length * 2);

        for (int i = 0; i < ba.length; i++) {
            sb.append(binToHexChar[(ba[i] & 0xf0) >> 4]);
            sb.append(binToHexChar[ba[i] & 0xf]);
        }

        return sb.toString();
    }

    public static byte[] hexStringToByteArray(String string) throws IllegalArgumentException {

        if (string == null) {
            throw new IllegalArgumentException("null");
        }

        int strlength = string.length();

        if (strlength % 2 != 0) {
            throw new IllegalArgumentException("Invalid string length.");
        }


        int    length = strlength / 2;
        byte[] ba     = new byte[length];


        for (int i = 0; i < length; i++) {
            int value1 = Character.digit(string.charAt(i * 2), 16);
            int value2 = Character.digit(string.charAt(i * 2 + 1), 16);

            if ((value1 == -1) || (value2 == -1)) {
                throw new IllegalArgumentException("Invalid character.");
            }

            ba[i] = (byte) ((value1 << 4) + value2);
        }

        return ba;
    }

    public static void hexStringToByteArray(String string, byte[] out, int offset) throws IllegalArgumentException {

        if ((string == null) || (out == null)) {
            throw new IllegalArgumentException("null pointer.");
        }


        int strlength = string.length();

        if (strlength % 2 != 0) {
            throw new IllegalArgumentException("Invalid string length.");
        }

        int length = strlength / 2;

        if (out.length - offset < length) {
            throw new IllegalArgumentException("Out to short for result.");
        }

        for (int i = 0; i < length; i++) {
            int value1 = Character.digit(string.charAt(i * 2), 16);
            int value2 = Character.digit(string.charAt(i * 2 + 1), 16);

            if ((value1 == -1) || (value2 == -1)) {
                throw new IllegalArgumentException("Invalid character.");
            }

            out[offset + i] = (byte) ((value1 << 4) + value2);
        }
    }

    public static byte[] blockInverter(byte[] aBlock){
         byte[] newBlock = new byte[aBlock.length];
         for (int c=0;c<aBlock.length;c++){
             newBlock[c]=aBlock[(aBlock.length-1)-c];
         }
         return newBlock;
     }

    public static byte[] xor(byte[] in1,byte[] in2){
        byte[] out = new byte[in1.length];
        for (int c=0;c<in1.length;c++){
            out[c]=(byte)((byte)in1[c]^(byte)in2[c]);
        }
        return out;

    }
    public static byte[] loadAFile(File aFile){
    try{
    byte[] buffer = new byte[(int)aFile.length()];
    FileInputStream fis = new FileInputStream(aFile);
    int pos=0;
    while (pos<aFile.length()){
        int len=fis.read(buffer,pos,(int)aFile.length()-pos);
        pos=pos+len;
        }
    fis.close();
    return buffer;
    }catch(Exception e){
        e.printStackTrace();
        }
        return null;
    }

    public static byte[] hashFile(File aFile){
        byte[] fileData=loadAFile(aFile);
        if (fileData==null) return null;
        try{
            MessageDigest sha1 = MessageDigest.getInstance("SHA1");
            return sha1.digest(fileData);
        }catch(Exception e){
            e.printStackTrace();
        }
        return null;
    }

}